@@ -1,7 +1,9 @@
 import boto3
 import warnings
+import ipdb
 warnings.simplefilter(action='ignore')
 import pandas as pd
+import humanize
 
 def parse_keys(x):
     try:
@@ -26,11 +28,17 @@ def get_ec2(status: str, profile: str, filter: str):
         return f'No instances running for {profile} with filter {filter}'
     full_df = pd.concat(df_list,axis=1, sort=True).T
 
+    full_df['SG'] = [ ','.join([i['GroupName'] for i in f ]) for f in  full_df.SecurityGroups  ] 
+    
+    # humanize all LaunchTime timestamps
+    # full_df['LaunchTime'] = [ humanize.naturaltime(i) for i in full_df.LaunchTime.values]  - pd.Timestamp.now()
+    full_df['LaunchTime'] = full_df.LaunchTime.astype('int64').apply(lambda x: humanize.naturaldelta(pd.to_datetime(x)))
+
     # shorten CPU options
     full_df['CPUs'] = full_df.CpuOptions.apply(lambda x: x['CoreCount'])
     del full_df['CpuOptions']
 
-    target_columns = 'CPUs InstanceId InstanceType LaunchTime PublicIpAddress Tags PrivateIpAddress'.split(' ')
+    target_columns = 'CPUs InstanceId InstanceType LaunchTime SG PublicIpAddress Tags PrivateIpAddress'.split(' ')
 
     # check if tags present
     if 'Tags' not in full_df.columns:
