@@ -29,13 +29,15 @@ def dt_conv(l: str):
 
 
 def filter_term(term: tuple):
-    # TODO: does not seem to work properly
     # Logic: all filter terms need to _not_ match
-    if 'cd' in term[0]:
-        if term[0].split(' ')[1][0] not in ['~','/']:
-            return False
-        else:
-            return True
+    if 'cd' in term[0][:2]:
+        try:
+            if term[0].split(' ')[1][0] not in ['~','/']:
+                return False
+            else:
+                return True
+        except:
+            print(f"Error with {term[0]}")
 
     return all([ft not in term[0] for ft in FILTER_TERMS])
 
